searchData={"content_type":"text/markdown","items":[{"doc":"Hierarchical deterministic wallet. It has the following features:\n\n- Generate mnemonic\n- Generate seed from mnemonic\n- Generate master keys from seed\n- Derive private and public keys from the master key\n- Various utility functions to work with derivation path, keys, crypto addresses","ref":"Cryptopunk.html","title":"Cryptopunk","type":"module"},{"doc":"Generate a mnemonic with the given number of words (24 by default).\nSee https://github.com/bitcoin/bips/blob/master/bip-0039.mediawiki\n\nExamples:\n\n    iex> mnemonic1 = Cryptopunk.create_mnemonic()\n    iex> mnemonic2 = Cryptopunk.create_mnemonic()\n    iex> mnemonic1 |> String.split(\" \") |> Enum.count()\n    24\n    iex> mnemonic1 != mnemonic2\n    true","ref":"Cryptopunk.html#create_mnemonic/1","title":"Cryptopunk.create_mnemonic/1","type":"function"},{"doc":"Generate mnemonic from entropy.\n\nExamples:\n\n    iex> bytes =  >\n    iex> Cryptopunk.create_mnemonic_from_entropy(bytes)\n    \"almost coil firm shield cement hobby fan cage wine idea track prison scale alone close favorite limb still\"","ref":"Cryptopunk.html#create_mnemonic_from_entropy/1","title":"Cryptopunk.create_mnemonic_from_entropy/1","type":"function"},{"doc":"Generate seed from mnemonic.\nSee https://github.com/bitcoin/bips/blob/master/bip-0039.mediawiki#from-mnemonic-to-seed\n\nExamples:\n\n    iex> mnemonic = \"almost coil firm shield cement hobby fan cage wine idea track prison scale alone close favorite limb still\"\n    iex> Cryptopunk.create_seed(mnemonic)\n     >","ref":"Cryptopunk.html#create_seed/2","title":"Cryptopunk.create_seed/2","type":"function"},{"doc":"Derives key\nhttps://github.com/bitcoin/bips/blob/master/bip-0032.mediawiki\n\nExamples:\n\n    iex> seed =  >\n    iex> {:ok, path} = Cryptopunk.parse_path(\"m / 44' / 0' / 0' / 0 / 0\")\n    iex> seed |> Cryptopunk.master_key_from_seed() |> Cryptopunk.derive_key(path)\n    %Cryptopunk.Key{chain_code:  >, depth: 5, index: 0, key:  >, parent_fingerprint:  >, type: :private}","ref":"Cryptopunk.html#derive_key/2","title":"Cryptopunk.derive_key/2","type":"function"},{"doc":"Deserialize extended key\n\nExamples:\n\n    iex>  Cryptopunk.deserialize_key(\"xprv9s21ZrQH143K3bGcMmWrLU2jguNt5HPuMcuW2ZSTmHWPecUNW1hZgfyGyTLZYEALk46YzbEiPL7v3s2SDxgdbhHF7SiKiMAz4kVx9u5gfr9\")\n    %Cryptopunk.Key{chain_code:  >, depth: 0, index: 0, key:  >, parent_fingerprint:  >, type: :private}","ref":"Cryptopunk.html#deserialize_key/1","title":"Cryptopunk.deserialize_key/1","type":"function"},{"doc":"Generate master private key from seed\nSee https://github.com/bitcoin/bips/blob/master/bip-0032.mediawiki#master-key-generation\n\nExamples:\n\n    iex> seed =  >\n    iex> Cryptopunk.master_key_from_seed(seed)\n    %Cryptopunk.Key{\n       chain_code:\n          >,\n       key:\n          >,\n       type: :private,\n       depth: 0,\n       parent_fingerprint:  >,\n       index: 0\n     }","ref":"Cryptopunk.html#master_key_from_seed/1","title":"Cryptopunk.master_key_from_seed/1","type":"function"},{"doc":"Parse derivation path\nSee https://github.com/bitcoin/bips/blob/master/bip-0044.mediawiki\n\nExamples:\n\n    iex> Cryptopunk.parse_path(\"m / 44' / 0' / 0' / 0 / 0\")\n    {:ok, %Cryptopunk.Derivation.Path{account: 0, address_index: 0, change: 0, coin_type: 0, purpose: 44, type: :private}}","ref":"Cryptopunk.html#parse_path/1","title":"Cryptopunk.parse_path/1","type":"function"},{"doc":"Serialize extended key\nSee https://github.com/bitcoin/bips/blob/master/bip-0032.mediawiki#Serialization_format\n\nExamples:\n\n    iex> seed =  >\n    iex> seed |> Cryptopunk.master_key_from_seed() |> Cryptopunk.serialize_key( >)\n    \"xprv9s21ZrQH143K3bGcMmWrLU2jguNt5HPuMcuW2ZSTmHWPecUNW1hZgfyGyTLZYEALk46YzbEiPL7v3s2SDxgdbhHF7SiKiMAz4kVx9u5gfr9\"","ref":"Cryptopunk.html#serialize_key/2","title":"Cryptopunk.serialize_key/2","type":"function"},{"doc":"Bitcoin address generation logic.\n\nAll addresses use compressed public keys.","ref":"Cryptopunk.Crypto.Bitcoin.html","title":"Cryptopunk.Crypto.Bitcoin","type":"module"},{"doc":"Generate a bech32 segwit address\n\nIt accepts three parameters:\n\n- public or private key. if a private key is provided, it will be converted to public key.\n- network (`:mainnet`, `:testnet` or `:regtest`)\n- optional parameters. Currently the only allowed parameter is a witness version (`:version`).\n\nExamples:\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Bitcoin.bech32_address(private_key, :mainnet)\n    \"bc1qc89hn5kmwxl804yfqmd97st3trarqr24y2hpqh\"\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Bitcoin.bech32_address(private_key, :mainnet, version: 1)\n    \"bc1pc89hn5kmwxl804yfqmd97st3trarqr246gsxg7\"\n\n    iex> public_key = %Cryptopunk.Key{key:  >, type: :public}\n    iex> Cryptopunk.Crypto.Bitcoin.bech32_address(public_key, :testnet)\n    \"tb1qx3ppj0smkuy3d6g525sh9n2w9k7fm7q3vh5ssm\"","ref":"Cryptopunk.Crypto.Bitcoin.html#bech32_address/3","title":"Cryptopunk.Crypto.Bitcoin.bech32_address/3","type":"function"},{"doc":"Generate a legacy (P2PKH) address.\n\nIt accepts three parameters:\n\n- public or private key. if a private key is provided, it will be converted to public key.\n- network (`:mainnet` or `:testnet`)\n- optional keyword params. Currently, the only allowed parameter is `:uncompressed` key. Passing `[uncompressed: true]` will generate the address from the uncompressed public key which is not advised. but it may be required for compatibility reasons\n\nExamples:\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Bitcoin.legacy_address(private_key, :mainnet)\n    \"1JfhAmwWjbGJ3RW2hjoRdmpKaKXgCjSwEL\"\n\n    iex> public_key = %Cryptopunk.Key{key:  >, type: :public}\n    iex> Cryptopunk.Crypto.Bitcoin.legacy_address(public_key, :testnet)\n    \"mkHGce7dctSxHgaWSSbmmrRWsZfzz7MxMk\"\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Bitcoin.legacy_address(private_key, :mainnet, uncompressed: true)\n    \"1AqWUNX6mdaiPay55BqZcAMqNSEJgcgj1D\"","ref":"Cryptopunk.Crypto.Bitcoin.html#legacy_address/3","title":"Cryptopunk.Crypto.Bitcoin.legacy_address/3","type":"function"},{"doc":"Generate a 'Pay to Witness Public Key Hash nested in BIP16 Pay to Script Hash' (P2WPKH-P2SH) address\n\nIt accepts two parameters:\n\n- public or private key. if a private key is provided, it will be converted to public key.\n- network (`:mainnet` or `:testnet`)\n\nExamples:\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Bitcoin.p2sh_p2wpkh_address(private_key, :mainnet)\n    \"397Y4wveZFbdEo8rTzXSPHWYuamfKs2GWd\"\n\n    iex> public_key = %Cryptopunk.Key{key:  >, type: :public}\n    iex> Cryptopunk.Crypto.Bitcoin.p2sh_p2wpkh_address(public_key, :testnet)\n    \"2NFNttcoWjE7WUcByBqpPKkcjg8wzgnU5HE\"","ref":"Cryptopunk.Crypto.Bitcoin.html#p2sh_p2wpkh_address/2","title":"Cryptopunk.Crypto.Bitcoin.p2sh_p2wpkh_address/2","type":"function"},{"doc":"Generate a P2SH-P2WPKH (nested segwit) redeem script from the given private or public key\n\n\n  Examples\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Bitcoin.p2sh_p2wpkh_redeem_script(private_key, :binary)\n     >\n\n    iex> public_key = %Cryptopunk.Key{key:  >, type: :public}\n    iex> Cryptopunk.Crypto.Bitcoin.p2sh_p2wpkh_redeem_script(public_key, :hex)\n    \"00143442193e1bb70916e914552172cd4e2dbc9df811\"","ref":"Cryptopunk.Crypto.Bitcoin.html#p2sh_p2wpkh_redeem_script/2","title":"Cryptopunk.Crypto.Bitcoin.p2sh_p2wpkh_redeem_script/2","type":"function"},{"doc":"Validate a bitcoin address\n\nExamples\n\n    iex> Bitcoin.validate(\"bc1qc89hn5kmwxl804yfqmd97st3trarqr24y2hpqh\")\n    {:ok, %{network: :mainnet, type: :p2wpkh}}\n\n    iex> Bitcoin.validate(\"1AqWUNX6mdaiPay55BqZcAMqNSEJgcgj1D\")\n    {:ok, %{network: :mainnet, type: :p2pkh}}\n\n    iex> Bitcoin.validate(\"0AqWUNX6mdaiPay55BqZcAMqNSEJgcgj1D\")\n    {:error, :invalid_address}","ref":"Cryptopunk.Crypto.Bitcoin.html#validate/1","title":"Cryptopunk.Crypto.Bitcoin.validate/1","type":"function"},{"doc":"Dogecoin address generation logic. It's similar to bitcoin legacy addresses.","ref":"Cryptopunk.Crypto.Dogecoin.html","title":"Cryptopunk.Crypto.Dogecoin","type":"module"},{"doc":"Generate a dogecoin address.\n\nIt accepts three parameters:\n\n- public or private key. if a private key is provided, it will be converted to public key.\n- network (`:mainnet` or `:testnet`)\n- optional keyword params. Currently, the only allowed parameter is `:uncompressed` key. Passing `[uncompressed: true]` will generate the address from the uncompressed public key which is not advised. but it may be required for compatibility reasons\n\nExamples:\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Dogecoin.address(private_key, :mainnet)\n    \"DNoni2tA31AaaRgdSKnzBXyvTTFyabwPKi\"\n\n    iex> public_key = %Cryptopunk.Key{key:  >, type: :public}\n    iex> Cryptopunk.Crypto.Dogecoin.address(public_key, :testnet)\n    \"nYxUariD3FNhvYrgVHGQk6y68aBtLHP87b\"\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Dogecoin.address(private_key, :mainnet, uncompressed: true)\n    \"DEyc1dTk53Uzvb9fomq89vXSFZxc2ZcRbs\"","ref":"Cryptopunk.Crypto.Dogecoin.html#address/3","title":"Cryptopunk.Crypto.Dogecoin.address/3","type":"function"},{"doc":"Ethereum address generation logic","ref":"Cryptopunk.Crypto.Ethereum.html","title":"Cryptopunk.Crypto.Ethereum","type":"module"},{"doc":"Generate an ethereum address. EVM compatible chains (for example Binance Smart Chain) may use the same address format.\n\nExamples:\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Ethereum.address(private_key)\n    \"0x74510e5055179bcf406d0e7449b47dee9f81e8b7\"\n\n    iex> public_key = %Cryptopunk.Key{key:  >, type: :public}\n    iex> Cryptopunk.Crypto.Ethereum.address(public_key)\n    \"0x056db290f8ba3250ca64a45d16284d04bc6f5fbf\"","ref":"Cryptopunk.Crypto.Ethereum.html#address/1","title":"Cryptopunk.Crypto.Ethereum.address/1","type":"function"},{"doc":"Encode an address in the EIP-55 mixed-case checksum encoding\n\nExamples:\n\n    iex> Cryptopunk.Crypto.Ethereum.checksum_encode(\"0xea0a6e3c511bbd10f4519ece37dc24887e11b55d\")\n    {:ok, \"0xea0A6E3c511bbD10f4519EcE37Dc24887e11b55d\"}\n\n    iex> Cryptopunk.Crypto.Ethereum.checksum_encode(\"0x52908400098527886e0f7030069857d2e4169ee7\")\n    {:ok, \"0x52908400098527886E0F7030069857D2E4169EE7\"}\n\n    iex> Cryptopunk.Crypto.Ethereum.checksum_encode(\"0x52908400098527886e0f7030069857d2e4169ee\")\n    {:error, :invalid_address_length}","ref":"Cryptopunk.Crypto.Ethereum.html#checksum_encode/1","title":"Cryptopunk.Crypto.Ethereum.checksum_encode/1","type":"function"},{"doc":"Validate an ethereum address\n\nExamples:\n\n    iex> Cryptopunk.Crypto.Ethereum.valid?(\"0xea0a6e3c511bbd10f4519ece37dc24887e11b55d\")\n    true\n\n    iex> Cryptopunk.Crypto.Ethereum.valid?(\"0xea0a6e3c511bbd10f4519ece37dc24887e11b55D\")\n    false","ref":"Cryptopunk.Crypto.Ethereum.html#valid?/1","title":"Cryptopunk.Crypto.Ethereum.valid?/1","type":"function"},{"doc":"Tron address generation logic.","ref":"Cryptopunk.Crypto.Tron.html","title":"Cryptopunk.Crypto.Tron","type":"module"},{"doc":"Generate a tron address.\n\nIt accepts two parameters:\n\n- public or private key. if a private key is provided, it will be converted to public key.\n- network (`:mainnet` or `:testnet`)\n\nExamples:\n\n    iex> private_key = %Cryptopunk.Key{key:  >, type: :private}\n    iex> Cryptopunk.Crypto.Tron.address(private_key, :mainnet)\n    \"TLaEVB6foF9nPn4sqscXc5jeH1PVyLwwFK\"\n\n    iex> public_key = %Cryptopunk.Key{key:  >, type: :public}\n    iex> Cryptopunk.Crypto.Tron.address(public_key, :testnet)\n    \"27PaDLFYbGN9ztPPT3YiTatLQEdEJ2xsfWM\"","ref":"Cryptopunk.Crypto.Tron.html#address/2","title":"Cryptopunk.Crypto.Tron.address/2","type":"function"},{"doc":"Implements key derivation logic.\n\nSee https://github.com/bitcoin/bips/blob/master/bip-0032.mediawiki","ref":"Cryptopunk.Derivation.html","title":"Cryptopunk.Derivation","type":"module"},{"doc":"","ref":"Cryptopunk.Derivation.html#derive/2","title":"Cryptopunk.Derivation.derive/2","type":"function"},{"doc":"","ref":"Cryptopunk.Derivation.html#do_derive/2","title":"Cryptopunk.Derivation.do_derive/2","type":"function"},{"doc":"Utility functions to work with deriviation path\n\nSee https://github.com/bitcoin/bips/blob/master/bip-0044.mediawiki","ref":"Cryptopunk.Derivation.Path.html","title":"Cryptopunk.Derivation.Path","type":"module"},{"doc":"","ref":"Cryptopunk.Derivation.Path.html#is_hardened/1","title":"Cryptopunk.Derivation.Path.is_hardened/1","type":"macro"},{"doc":"","ref":"Cryptopunk.Derivation.Path.html#is_normal/1","title":"Cryptopunk.Derivation.Path.is_normal/1","type":"macro"},{"doc":"","ref":"Cryptopunk.Derivation.Path.html#new/1","title":"Cryptopunk.Derivation.Path.new/1","type":"function"},{"doc":"","ref":"Cryptopunk.Derivation.Path.html#parse/1","title":"Cryptopunk.Derivation.Path.parse/1","type":"function"},{"doc":"","ref":"Cryptopunk.Derivation.Path.html#to_raw_path/1","title":"Cryptopunk.Derivation.Path.to_raw_path/1","type":"function"},{"doc":"","ref":"Cryptopunk.Derivation.Path.html#two_power_31/0","title":"Cryptopunk.Derivation.Path.two_power_31/0","type":"function"},{"doc":"","ref":"Cryptopunk.Derivation.Path.html#t:raw_path/0","title":"Cryptopunk.Derivation.Path.raw_path/0","type":"type"},{"doc":"","ref":"Cryptopunk.Derivation.Path.html#t:t/0","title":"Cryptopunk.Derivation.Path.t/0","type":"type"},{"doc":"Utility functions to work with keys","ref":"Cryptopunk.Key.html","title":"Cryptopunk.Key","type":"module"},{"doc":"","ref":"Cryptopunk.Key.html#deserialize/1","title":"Cryptopunk.Key.deserialize/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#master_key/1","title":"Cryptopunk.Key.master_key/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#new/1","title":"Cryptopunk.Key.new/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#new_master_private/1","title":"Cryptopunk.Key.new_master_private/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#new_master_public/1","title":"Cryptopunk.Key.new_master_public/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#new_private/1","title":"Cryptopunk.Key.new_private/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#new_public/1","title":"Cryptopunk.Key.new_public/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#public_from_private/1","title":"Cryptopunk.Key.public_from_private/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#serialize/2","title":"Cryptopunk.Key.serialize/2","type":"function"},{"doc":"","ref":"Cryptopunk.Key.html#t:t/0","title":"Cryptopunk.Key.t/0","type":"type"},{"doc":"Extended key serialization logic","ref":"Cryptopunk.Key.Serialization.html","title":"Cryptopunk.Key.Serialization","type":"module"},{"doc":"","ref":"Cryptopunk.Key.Serialization.html#decode/1","title":"Cryptopunk.Key.Serialization.decode/1","type":"function"},{"doc":"","ref":"Cryptopunk.Key.Serialization.html#encode/2","title":"Cryptopunk.Key.Serialization.encode/2","type":"function"},{"doc":"Wallet import format (WIF) encoding","ref":"Cryptopunk.Key.WIF.html","title":"Cryptopunk.Key.WIF","type":"module"},{"doc":"","ref":"Cryptopunk.Key.WIF.html#decode/2","title":"Cryptopunk.Key.WIF.decode/2","type":"function"},{"doc":"","ref":"Cryptopunk.Key.WIF.html#encode/2","title":"Cryptopunk.Key.WIF.encode/2","type":"function"},{"doc":"Implements seed generation logic.\n\nSee https://github.com/bitcoin/bips/blob/master/bip-0039.mediawiki#from-mnemonic-to-seed","ref":"Cryptopunk.Seed.html","title":"Cryptopunk.Seed","type":"module"},{"doc":"","ref":"Cryptopunk.Seed.html#create/2","title":"Cryptopunk.Seed.create/2","type":"function"},{"doc":"Utility functions","ref":"Cryptopunk.Utils.html","title":"Cryptopunk.Utils","type":"module"},{"doc":"","ref":"Cryptopunk.Utils.html#compress_public_key/1","title":"Cryptopunk.Utils.compress_public_key/1","type":"function"},{"doc":"","ref":"Cryptopunk.Utils.html#decompress_public_key/1","title":"Cryptopunk.Utils.decompress_public_key/1","type":"function"},{"doc":"","ref":"Cryptopunk.Utils.html#hash160/1","title":"Cryptopunk.Utils.hash160/1","type":"function"},{"doc":"","ref":"Cryptopunk.Utils.html#hmac_sha512/2","title":"Cryptopunk.Utils.hmac_sha512/2","type":"function"},{"doc":"","ref":"Cryptopunk.Utils.html#ripemd160_hash/1","title":"Cryptopunk.Utils.ripemd160_hash/1","type":"function"},{"doc":"","ref":"Cryptopunk.Utils.html#sha256_hash/1","title":"Cryptopunk.Utils.sha256_hash/1","type":"function"}]}